@@ -11,20 +11,28 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
+from .local_coffee_ware_house import CoffeeWareHouse
 from .local_company import Company
 from .local_document_type import DocumentType
+from .local_offer import Offer
 from .local_product import Product
+from .local_state_machine import StateMachine
+from .oasis_associate_balance import AssociateBalance
 from .oasis_client import OasisClient
 from .oasis_company import OasisCompany
 from .oasis_cycle import Cycle
 from .oasis_discount import OasisDiscount
 from .oasis_geographic_location import OasisGeographicLocation
+from .oasis_location import OasisLocation
+from .oasis_operation import Operation
 from .oasis_periods import Periods
 from .oasis_product import OasisProduct
 from .oasis_type_client import OasisTypeClient
 
 
 __all__ = [
+    "AssociateBalance",
+    "CoffeeWareHouse",
     "Company",
     "Cycle",
     "DocumentType",
@@ -32,7 +40,9 @@ __all__ = [
     "OasisCompany",
     "OasisDiscount",
     "OasisGeographicLocation",
+    "OasisLocation",
     "OasisProduct",
     "OasisTypeClient",
-    "Product"
+    "Product",
+    "StateMachine"
 ]
