@@ -12,7 +12,9 @@
 # Description:
 # ****************************************************************
 from .product import ProductListSerializer
+from .oasis_cycle import CycleSerializer
 
 __all__ = [
+    "CycleSerializer",
     "ProductListSerializer"
-]
\ No newline at end of file
+]
