@@ -11,32 +11,46 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
+from .local_models import CoffeeWareHouse
 from .local_models import Company
 from .local_models import DocumentType
+from .local_models import Offer
+from .local_models import OfferMov
 from .local_models import Product
+from .local_models import StateMachine
 from .oasis_models import Account
+from .oasis_models import AssociateBalance
 from .oasis_models import Classification
 from .oasis_models import Client
 from .oasis_models import Cycle
 from .oasis_models import Discount
 from .oasis_models import GeographicLocation
+from .oasis_models import Location
 from .oasis_models import OasisCompany
 from .oasis_models import OasisProduct
+from .oasis_models import Operation
 from .oasis_models import Periods
 from .oasis_models import TypeClient
 
 __all__ = [
+    "AssociateBalance",
     "Classification",
     "Client",
+    "CoffeeWareHouse",
     "Company",
     "Cycle",
     "Discount",
     "DocumentType",
     "GeographicLocation",
+    "Location",
     "Product",
     "OasisCompany",
     "OasisProduct",
+    "Offer",
+    "OfferMov",
+    "Operation",
     "Periods",
+    "StateMachine",
     "TypeClient"
 ]
 
