@@ -11,11 +11,13 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
+from .sync_coffee_ware_house import sync_coffee_ware_house
 from .sync_company import sync_company
 from .sync_document_types import sync_document_types
 from .sync_products import sync_products
 
 __all__ = [
+    "sync_coffee_ware_house",
     "sync_products",
     "sync_company",
     "sync_document_types"
